==> qtjambi-scxml-6.2.7-sources.jar: io/qt/scxml/QScxmlStaticScxmlServiceFactory.java <==
package io.qt.scxml;


/**
 * <p>Creates SCXML service instances from precompiled documents</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qscxmlstaticscxmlservicefactory.html">QScxmlStaticScxmlServiceFactory</a></p>
 */
public class QScxmlStaticScxmlServiceFactory extends io.qt.scxml.QScxmlInvokableServiceFactory
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlStaticScxmlServiceFactory.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlStaticScxmlServiceFactory(io.qt.core.QMetaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlStaticScxmlServiceFactory(io.qt.core.QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> nameList, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters) {
        this(metaObject, invokeInfo, nameList, parameters, (io.qt.core.QObject)null);
    }
    
    public QScxmlStaticScxmlServiceFactory(io.qt.core.QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> nameList, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, metaObject, invokeInfo, nameList, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlStaticScxmlServiceFactory instance, io.qt.core.QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> nameList, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::invoke(QScxmlStateMachine*)</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlInvokableService invoke(io.qt.scxml.QScxmlStateMachine parentStateMachine){
        return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlStaticScxmlServiceFactory(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-scxml-6.2.8-sources.jar: io/qt/scxml/QScxmlStaticScxmlServiceFactory.java <==
package io.qt.scxml;


/**
 * <p>Creates SCXML service instances from precompiled documents</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qscxmlstaticscxmlservicefactory.html">QScxmlStaticScxmlServiceFactory</a></p>
 */
public class QScxmlStaticScxmlServiceFactory extends io.qt.scxml.QScxmlInvokableServiceFactory
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlStaticScxmlServiceFactory.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlStaticScxmlServiceFactory(io.qt.core.QMetaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlStaticScxmlServiceFactory(io.qt.core.QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> nameList, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters) {
        this(metaObject, invokeInfo, nameList, parameters, (io.qt.core.QObject)null);
    }
    
    public QScxmlStaticScxmlServiceFactory(io.qt.core.QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> nameList, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, metaObject, invokeInfo, nameList, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlStaticScxmlServiceFactory instance, io.qt.core.QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.Integer> nameList, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::invoke(QScxmlStateMachine*)</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlInvokableService invoke(io.qt.scxml.QScxmlStateMachine parentStateMachine){
        return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlStaticScxmlServiceFactory(QPrivateConstructor p) { super(p); } 
    
}
